﻿using System;
using Infragistics;
using Foundation;
using UIKit;

namespace CustomSparklineColumn_Xamarin
{
	public class CurrentRecordColumnDefinition : IGGridViewColumnDefinition
	{
		public CurrentRecordColumnDefinition (string key) : base (key)
		{
		}

		// in this case we want to format the data going into the underlying textLabel and assign it to the textLabel.attributedText.
		public override IGGridViewCell CreateCell (IGGridView gridView, IGCellPath path, IGGridViewDataSourceHelper dataSource)
		{
			// first we see if we can grab a cell from the recycler
			IGGridViewCell cell = (IGGridViewCell)gridView.DequeueReusableCell ("");
			if (cell == null) {
				// nope, make a new one
				cell = new IGGridViewCell ("CurrentRecordCell");
			}

			// get the data object that is going to be associated with the row, and send it to a method to generate the text we want to display.

			TeamSeasonData data = (TeamSeasonData)dataSource.ResolveDataObjectForRow (path);

			// set the textLabel.attributedText.  Since we aren't making a custom cell we are using default IGGridVeiwCell object and just modifing what is being shown.
			cell.TextLabel.AttributedText = this.GenerateText (data);

			return cell;
		}

		private NSAttributedString GenerateText(TeamSeasonData data)
		{
			int wins = 0;
			int losses = 0;
			int ties = 0;

			if (data != null) {
				for (int i = 0; i < data.RecordData.Length; i++) {
					NSNumber value =(NSNumber)data.RecordData[i]; 
					if (value.Int16Value == 0)
						ties++;
					else if (value.Int16Value > 0)
						wins++;
					else
						losses++;
				}
			}

			NSMutableAttributedString attrString = new NSMutableAttributedString ();

			NSMutableAttributedString winString = new NSMutableAttributedString (new NSAttributedString (wins.ToString() ));
			NSRange winRange;
			winRange.Length = winString.Length;
			winRange.Location = 0;
			winString.AddAttribute (UIStringAttributeKey.ForegroundColor , UIColor.Blue, winRange);


			NSMutableAttributedString lossString = new NSMutableAttributedString (new NSAttributedString (losses.ToString() ));
			NSRange lossesRange;
			lossesRange.Length = lossString.Length;
			lossesRange.Location = 0;
			lossString.AddAttribute (UIStringAttributeKey.ForegroundColor, UIColor.Red, lossesRange);

			attrString.Append (winString);
			attrString.Append (new NSAttributedString (" - "));
			attrString.Append (lossString);
			attrString.Append (new NSAttributedString (" - "));
			attrString.Append (new NSAttributedString( ties.ToString()));

			return attrString;
		}
	}
}

